@@ -1,29 +1,43 @@
-import pytest
-import requests
+import pickle
 
-from schema_registry.client import SchemaRegistryClient, schema
+import pytest
+
+import httpx
+from schema_registry.client import SchemaRegistryClient, schema, utils
 from tests import data_gen
 
 
-def test_context(client):
-    with client as c:
-        parsed = schema.AvroSchema(data_gen.BASIC_SCHEMA)
-        schema_id = c.register("test-basic-schema", parsed)
-        assert schema_id > 0
-        assert len(c.id_to_schema) == 1
-
-
-def test_cert_no_key():
-    with pytest.raises(AssertionError):
+def test_invalid_cert():
+    with pytest.raises(FileNotFoundError):
         SchemaRegistryClient(url="https://127.0.0.1:65534", cert_location="/path/to/cert")
 
 
-def test_cert_with_key():
+def test_cert_with_key(certificates):
     client = SchemaRegistryClient(
-        url="https://127.0.0.1:65534", cert_location="/path/to/cert", key_location="/path/to/key"
+        url="https://127.0.0.1:65534",
+        cert_location=certificates["certificate"],
+        key_location=certificates["key"],
+        key_password=certificates["password"],
     )
 
-    assert ("/path/to/cert", "/path/to/key") == client.cert
+    assert client.conf[utils.SSL_CERTIFICATE_LOCATION] == certificates["certificate"]
+    assert client.conf[utils.SSL_KEY_LOCATION] == certificates["key"]
+    assert client.conf[utils.SSL_KEY_PASSWORD] == certificates["password"]
+
+
+def test_pickelable(client):
+    unpickled_client = pickle.loads(pickle.dumps(client))
+
+    assert client == unpickled_client
+
+    # make sure that is possible to do client operations with unpickled_client
+    subject = "test-basic-schema"
+    parsed = schema.AvroSchema(data_gen.BASIC_SCHEMA)
+    unpickled_client.get_subjects()
+    schema_id = unpickled_client.register(subject, parsed)
+
+    assert schema_id > 0
+    assert unpickled_client.delete_subject(subject)
 
 
 def test_custom_headers():
@@ -42,9 +56,7 @@ def test_override_headers(client, deployment_schema, mocker, response_klass):
     subject = "test"
     override_header = {"custom-serialization": "application/avro"}
 
-    request_patch = mocker.patch.object(
-        requests.sessions.Session, "request", return_value=response_klass(200, content={"id": 1})
-    )
+    request_patch = mocker.patch.object(httpx.Client, "request", return_value=response_klass(200, content={"id": 1}))
     client.register(subject, deployment_schema, headers=override_header)
 
     prepare_headers = client.prepare_headers(body="1")
@@ -54,17 +66,18 @@ def test_override_headers(client, deployment_schema, mocker, response_klass):
 
 
 def test_cert_path():
-    client = SchemaRegistryClient(url="https://127.0.0.1:65534", ca_location="/path/to/ca")
+    client = SchemaRegistryClient(url="https://127.0.0.1:65534", ca_location=True)
 
-    assert "/path/to/ca" == client.verify
+    assert client.conf[utils.SSL_CA_LOCATION]
 
 
-def test_init_with_dict():
+def test_init_with_dict(certificates):
     client = SchemaRegistryClient(
         {
             "url": "https://127.0.0.1:65534",
-            "ssl.certificate.location": "/path/to/cert",
-            "ssl.key.location": "/path/to/key",
+            "ssl.certificate.location": certificates["certificate"],
+            "ssl.key.location": certificates["key"],
+            "ssl.key.password": certificates["password"],
         }
     )
     assert "https://127.0.0.1:65534/" == client.url_manager.url
@@ -93,7 +106,7 @@ def test_invalid_url():
 def test_basic_auth_url():
     client = SchemaRegistryClient({"url": "https://user_url:secret_url@127.0.0.1:65534"})
 
-    assert ("user_url", "secret_url") == client.auth
+    assert ("user_url", "secret_url") == client.session.auth
 
 
 def test_basic_auth_userinfo():
@@ -104,7 +117,7 @@ def test_basic_auth_userinfo():
             "basic.auth.user.info": "user_userinfo:secret_userinfo",
         }
     )
-    assert ("user_userinfo", "secret_userinfo") == client.auth
+    assert ("user_userinfo", "secret_userinfo") == client.session.auth
 
 
 def test_basic_auth_sasl_inherit():
@@ -117,7 +130,7 @@ def test_basic_auth_sasl_inherit():
             "sasl.password": "secret_sasl",
         }
     )
-    assert ("user_sasl", "secret_sasl") == client.auth
+    assert ("user_sasl", "secret_sasl") == client.session.auth
 
 
 def test_basic_auth_invalid():
