@@ -1,6 +1,6 @@
 import pytest
-import requests
 
+import httpx
 from schema_registry.client import errors, schema
 from tests import data_gen
 
@@ -35,7 +35,7 @@ def test_update_global_compatibility(client):
 
 def test_update_compatibility_fail(client, response_klass, mocker):
     http_code = 404
-    mocker.patch.object(requests.sessions.Session, "request", return_value=response_klass(http_code))
+    mocker.patch.object(httpx.Client, "request", return_value=response_klass(http_code))
 
     with pytest.raises(errors.ClientError) as excinfo:
         client.update_compatibility("FULL", "test-user-schema")
